==> haskell-aeson-warning-parser-0.1.1-82-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-warning-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson-warning-parser
version:              0.1.1
visibility:           public
id:                   aeson-warning-parser-0.1.1-1qaJKKylgvWJNEzyMXaMt8
key:                  aeson-warning-parser-0.1.1-1qaJKKylgvWJNEzyMXaMt8
license:              BSD-3-Clause
copyright:            2018-2023 FP Complete
maintainer:           Mike Pilgrem <public@pilgrem.com>
author:               Michael Snoyman
homepage:
    https://github.com/commercialhaskell/aeson-warning-parser#readme

synopsis:
    Library providing JSON parser that warns about unexpected fields in objects.

description:
    Please see the README on GitHub at <https://github.com/commercialhaskell/aeson-warning-parser#readme>

category:             JSON
abi:                  ce2a7f51f056ffcb93ebcb59f4f1fb64
exposed:              True
exposed-modules:      Data.Aeson.WarningParser
hidden-modules:       Paths_aeson_warning_parser
import-dirs:          /usr/lib/ghc-9.6.6/site-local/aeson-warning-parser-0.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/aeson-warning-parser-0.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/aeson-warning-parser-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-warning-parser
hs-libraries:         HSaeson-warning-parser-0.1.1-1qaJKKylgvWJNEzyMXaMt8
depends:
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y base-4.18.2.1 containers-0.6.7
    generic-deriving-1.14.6-EuFohhXhdng2D0y7uvFJO5
    rio-0.1.24.0-FBO4PrA6UlqFqVtMb3OxSz
    rio-prettyprint-0.1.8.0-4VEed9eIFha1YPzhahlWIJ text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5

haddock-interfaces:
    /usr/share/doc/haskell-aeson-warning-parser/html/aeson-warning-parser.haddock

haddock-html:         /usr/share/doc/haskell-aeson-warning-parser/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-warning-parser-0.1.1-84-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-warning-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson-warning-parser
version:              0.1.1
visibility:           public
id:                   aeson-warning-parser-0.1.1-829Rb0i9qAn3xP5CrGnJv6
key:                  aeson-warning-parser-0.1.1-829Rb0i9qAn3xP5CrGnJv6
license:              BSD-3-Clause
copyright:            2018-2023 FP Complete
maintainer:           Mike Pilgrem <public@pilgrem.com>
author:               Michael Snoyman
homepage:
    https://github.com/commercialhaskell/aeson-warning-parser#readme

synopsis:
    Library providing JSON parser that warns about unexpected fields in objects.

description:
    Please see the README on GitHub at <https://github.com/commercialhaskell/aeson-warning-parser#readme>

category:             JSON
abi:                  66dfaf4e78a61bd8c7ab314bc0dd7515
exposed:              True
exposed-modules:      Data.Aeson.WarningParser
hidden-modules:       Paths_aeson_warning_parser
import-dirs:          /usr/lib/ghc-9.6.6/site-local/aeson-warning-parser-0.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/aeson-warning-parser-0.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/aeson-warning-parser-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-warning-parser
hs-libraries:         HSaeson-warning-parser-0.1.1-829Rb0i9qAn3xP5CrGnJv6
depends:
    aeson-2.2.0.0-Hqy1Zqe0ZE81dk2L20icmH base-4.18.2.1 containers-0.6.7
    generic-deriving-1.14.6-BFg0FP3W9JqCK2s6khW04t
    rio-0.1.24.0-KVtH5Pu4lMV2pIyCm3kd0p
    rio-prettyprint-0.1.8.0-HdRcgeWmvcfKcoZxpVmw1t text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-1hrud2F05KV7Rz7RsKTZ5O

haddock-interfaces:
    /usr/share/doc/haskell-aeson-warning-parser/html/aeson-warning-parser.haddock

haddock-html:         /usr/share/doc/haskell-aeson-warning-parser/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
